aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/di/extension/core.php
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/includes/di/extension/core.php')
-rw-r--r--phpBB/includes/di/extension/core.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/phpBB/includes/di/extension/core.php b/phpBB/includes/di/extension/core.php
index 701ae453d1..7dfdd6782a 100644
--- a/phpBB/includes/di/extension/core.php
+++ b/phpBB/includes/di/extension/core.php
@@ -29,16 +29,16 @@ class phpbb_di_extension_core extends Extension
* phpBB Root path
* @var string
*/
- protected $phpbb_root_path;
+ protected $root_path;
/**
* Constructor
*
* @param string $phpbb_root_path Root path
*/
- public function __construct($phpbb_root_path)
+ public function __construct($root_path)
{
- $this->phpbb_root_path = $phpbb_root_path;
+ $this->root_path = $root_path;
}
/**
@@ -51,9 +51,9 @@ class phpbb_di_extension_core extends Extension
*/
public function load(array $config, ContainerBuilder $container)
{
- if (file_exists($this->phpbb_root_path . 'config/services.yml'))
+ if (file_exists($this->root_path . 'config/services.yml'))
{
- $loader = new YamlFileLoader($container, new FileLocator(realpath($this->phpbb_root_path . 'config')));
+ $loader = new YamlFileLoader($container, new FileLocator(phpbb_realpath($this->root_path . 'config')));
$loader->load('services.yml');
}
}
@@ -29,16 +29,16 @@ class phpbb_di_extension_core extends Extension
* Constructor
*
- * @param string $phpbb_root_path Root path
+ * @param string $root_path Root path
*/